Share Apache Arrow objects between Python and R using rpy2.

![Python package](https://github.com/rpy2/rpy2-arrow/workflows/Python%20package/badge.svg)

This is still early work in progress, but there is
a [demo notebook](doc/notebooks/demo.ipynb).

